new;
cls;

library pgraph;
#include FINF.SRC;
#include UNIFORM.SRC;
#include Disutils.SRC;
format /rd/m1 8,4;
rndseed 20091103;
nsim = 500;
out1b = zeros(nsim,2);
out1t = zeros(nsim,2);
out2b = zeros(nsim,2);
out2t = zeros(nsim,2);
lambda_l = 0.6;
lambda_u = 0.99;
beta = 0.99;
rho = seqa(0.1,0.05,17);
sig = 0.01;
N = 100;
T = 200;

brpv = zeros(17,2);
bskew = zeros(17,2);
for k (1,17,1);
	
	k " th experiment";
	
	for sim (1,nsim,1);
		
	//=============================================================================
	//	Generate a wage process
	//=============================================================================
		dw = (sig/(1-rho[k]^2))*rndn(1,1);
		w = zeros(T+100,1);
		w[1] = dw;
		w[2] = (1+rho[k])*w[1] + sig*rndn(1,1);
		for i (3,T+100,1);
			w[i] = (1+rho[k])*w[i-1] - rho[k]*w[i-2] + sig*rndn(1,1);
		endfor;
		
	//=============================================================================
	//	Generate sectoral prices
	//=============================================================================	
		p = zeros(T+100,N);
		lambda = RUNIFORM(N,1,lambda_l,lambda_u);
		for i (1,N,1);
			ai = lambda[i];
			bi = (1-ai)/(1-ai*beta*rho[k]);
			ci = ai*(1-ai)*(beta*rho[k])/(1-ai*beta*rho[k]);
			p[1,i] = bi*w[1];
			for j (2,T+100,1); 
				p[j,i] = ai*p[j-1,i] + bi*w[j] - ci*w[j-1]; 
			endfor;
		endfor;
	
	//=============================================================================
	//	Final data
	//=============================================================================
		r = p - lagn(p,1); // inflation rates
		r = trimr(r,100,0); // remove the first 100 observations
		r_stats = zeros(T,10);
		for i (1,T,1);
			ri = r[i,.]';
			{ni,mi,medi,maxi,mini,stdi,si,ki,jbi,pvi} = stats(ri);
			r_stats[i,.] = ni~mi~medi~maxi~mini~stdi~si~ki~jbi~pvi;
		endfor;
		AGG = r_stats[.,2];
		RPV = r_stats[.,6];
		SKEW = r_stats[.,7];
		KURT = r_stats[.,8];
	
	//=============================================================================
	//	Regression Analysis
	//=============================================================================
		thd = meanc(AGG);
		AGG1 = AGG.*(AGG .<= thd);
		AGG2 = AGG.*(AGG .> thd);
		
	//=============================================================================
	//	RPV = (a1+b1*AGG)1{S1} + {a2+b2*AGG}1{S2}
	//=============================================================================
		y = RPV;
		x = AGG1~AGG2;
		c = ones(rows(x),1);
		x = c~x;
		bhat = inv(x'x)*x'y;
		s2 = vcx(y-x*bhat);
		vhat = s2*diag(inv(x'x));
		shat = sqrt(vhat);
		tval = bhat./shat;
		out1b[sim,.] = bhat[2]~bhat[3];
		out1t[sim,.] = tval[2]~tval[3];
		
	//=============================================================================
	//	SKEW = (a1+b1*AGG)1{S1} + {a2+b2*AGG}1{S2}
	//=============================================================================
		y = SKEW;
		x = AGG1~AGG2;
		c = ones(rows(x),1);
		x = c~x;
		bhat = inv(x'x)*x'y;
		s2 = vcx(y-x*bhat);
		vhat = s2*diag(inv(x'x));
		shat = sqrt(vhat);
		tval = bhat./shat;
		out2b[sim,.] = bhat[2]~bhat[3];
		out2t[sim,.] = tval[2]~tval[3];
	
	endfor;
	
	mean1 = meanc(out1b);
	med1 = median(out1b);
	brpv[k,.] = mean1';
	
	mean2 = meanc(out2b);
	med2 = median(out2b);
	bskew[k,.] = mean2';

endfor;

xlswritem(rho~brpv~bskew,"calvo-sim.xlsx","A2",1,"");
			
end ;
