new;
cls;
library pgraph;
#include FINF.SRC;
#include UNIFORM.SRC;
#include Disutils.SRC;
format /rd/m1 8,4;
//rndseed 20091103;
rndseed 20110614;
nsim = 500;
out1b = zeros(nsim,2);
out1t = zeros(nsim,2);
out2b = zeros(nsim,2);
out2t = zeros(nsim,2);

//=============================================================================
//	Preliminaries
//=============================================================================
let lambda_l[3,1] = 0.6 0.7 0.6;
let lambda_u[3,1] = 0.99 0.99 0.9;
beta = 0.99;
rho = seqa(0.1,0.05,17);
sig = 0.01;
N = 100;
T = 200;

brpv = zeros(17,2);
bskew = zeros(17,2);
for k (1,17,1);
	
	k " th experiment";
	
	for sim (1,nsim,1);
		
	//=============================================================================
	//	Generate a wage process
	//=============================================================================
		dw = (sig/(1-rho[k]^2))*rndn(1,1);
		w = zeros(T+100,1);
		w[1] = dw;
		w[2] = (1+rho[k])*w[1] + sig*rndn(1,1);
		for i (3,T+100,1);
			w[i] = (1+rho[k])*w[i-1] - rho[k]*w[i-2] + sig*rndn(1,1);
		endfor;
		
	//=============================================================================
	//	Generate sectoral prices
	//=============================================================================	
		p = zeros(T+100,N);
		lambda0 = RUNIFORM(N,1,lambda_l[1],lambda_u[1]);
	
		for i (1,N,1);
			a = lambda0[i];
			b = (1-a)/(1-a*beta*rho[k]);
			c = a*(1-a)*(beta*rho[k])/(1-a*beta*rho[k]);	
			p[1,i] = b*w[1];
		endfor;
	
		for i (2,T+100,1);
			lambda = zeros(N,1);
	
			l1 = indexcat(p[i-1,.]'.>w[i-1],1);		
			ind1 = sortind(p[i-1,l1]');
			n1 = rows(ind1);
			lambda1 = rev(sortc(RUNIFORM(n1,1,lambda_l[2],lambda_u[2]),1));
			lambda[l1] = lambda1[ind1];
		
			l2 = indexcat(p[i-1,.]'.<=w[i-1],1);
			ind2 = sortind(p[i-1,l2]');
			n2 = rows(ind2);
			lambda2 = sortc(RUNIFORM(n2,1,lambda_l[3],lambda_u[3]),1);
			lambda[l2] = lambda2[ind2];
							 
			for j (1,N,1);
				a = lambda[j]; 
				b = (1-a)/(1-a*beta*rho[k]); 
				c = a*(1-a)*(beta*rho[k])/(1-a*beta*rho[k]);			
				p[i,j] = a*p[i-1,j] + b*w[i] - c*w[i-1];
			endfor;
	
		endfor;
	
	//=============================================================================
	//	Final data
	//=============================================================================
		r = p - lagn(p,1); // inflation rates
		r = trimr(r,100,0); // remove the first 100 observations
		r_stats = zeros(T,10);
		for i (1,T,1);
			ri = r[i,.]';
			{ni,mi,medi,maxi,mini,stdi,si,ki,jbi,pvi} = stats(ri);
			r_stats[i,.] = ni~mi~medi~maxi~mini~stdi~si~ki~jbi~pvi;
		endfor;
		AGG = r_stats[.,2];
		RPV = r_stats[.,6];
		SKEW = r_stats[.,7];
		KURT = r_stats[.,8];
		
	//=============================================================================
	//	Regression Analysis
	//=============================================================================
		thd = meanc(AGG);
		AGG1 = AGG.*(AGG .<= thd);
		AGG2 = AGG.*(AGG .> thd);
		
	//=============================================================================
	//	RPV = (a1+b1*AGG)1{S1} + {a2+b2*AGG}1{S2}
	//=============================================================================
		y = RPV;
		x = AGG1~AGG2;
		c = ones(rows(x),1);
		x = c~x;
		bhat = inv(x'x)*x'y;
		s2 = vcx(y-x*bhat);
		vhat = s2*diag(inv(x'x));
		shat = sqrt(vhat);
		tval = bhat./shat;
		out1b[sim,.] = bhat[2]~bhat[3];
		out1t[sim,.] = tval[2]~tval[3];
		
	//=============================================================================
	//	SKEW = (a1+b1*AGG)1{S1} + {a2+b2*AGG}1{S2}
	//=============================================================================
		y = SKEW;
		x = AGG1~AGG2;
		c = ones(rows(x),1);
		x = c~x;
		bhat = inv(x'x)*x'y;
		s2 = vcx(y-x*bhat);
		vhat = s2*diag(inv(x'x));
		shat = sqrt(vhat);
		tval = bhat./shat;
		out2b[sim,.] = bhat[2]~bhat[3];
		out2t[sim,.] = tval[2]~tval[3];
	
	endfor;
	
	mean1 = meanc(out1b);
	med1 = median(out1b);
	brpv[k,.] = mean1';
	
	mean2 = meanc(out2b);
	med2 = median(out2b);
	bskew[k,.] = mean2';

endfor;

xlswritem(rho~brpv~bskew,"calvo-sim.xlsx","A2",4,"");
			
end ;
