//	===========================================================================
	new;
	cls;
//	===========================================================================	
	library pgraph;
	#include FINF.SRC;
	#include UNIFORM.SRC;
	#include Disutils.SRC;
	format /rd/m1 8,4;
	rndseed 20091103;
	rho = 0.9;
	sig = 0.01;
	N = 85;
	T = 134;
	ng = 1024;
	lb = -6; // scalar
	ub = 6; // scalar
	dt = (ub-lb)/(ng-1); // scalar
	tic = seqa(lb-dt,dt,ng); // ngx1
	h = 1.06;
	tmp = xlsreadm("parameters","B2:E86",1,"");
	l = tmp[.,1]; // lambda
	l[indexcat(l.>=1,1)] = 0.99*ones(sumc(l.>=1),1);
	g = tmp[.,2]; // gamma
	d = tmp[.,3]; // delta
	p1 = tmp[.,4]; // log(P(i1))
	
//	===========================================================================
//	Generate a wage process
//	===========================================================================
	if rho == 1;
		dw = 0;
	else;
		dw = (sig/(1-rho^2))*rndn(1,1);
	endif;
	w = zeros(T,1);
	w[1] = dw;
	w[2] = (1+rho)*w[1]+sig*rndn(1,1);
	for i (3,T,1);
		w[i] = (1+rho)*w[i-1]-rho*w[i-2]+sig*rndn(1,1);
	endfor;
	
//	===========================================================================
//	Generate sectoral prices
//	===========================================================================
	p = zeros(T,N);
	for i (1,N,1);
		ai = l[i]; // lambda
		bi = g[i]; // gamma
		ci = d[i]; // -delta
		p[1,i] = p1[i];
		for j (2,T,1); 
			p[j,i] = ai*p[j-1,i]+bi*w[j]+ci*w[j-1]; 
		endfor;
	endfor;
	r = p-lagn(p,1); // TxN, price changes

//	===========================================================================
//	standardised price change
//	===========================================================================
	z = zeros(T-1,N); // TxN
	for i (2,T,1);
		ri = r[i,.]'; // Nx1
		rmi = meanc(packr(ri)); // scalar
		rsi = stdc(packr(ri)); // scalar
		zi = (ri-rmi)/rsi; // Nx1
		z[i-1,.] = zi'; // 1xN
	endfor;

//	===========================================================================
//	cross-sectional distribution
//	===========================================================================
	f = zeros(T-1,ng); // Txng
	for i (1,T-1,1);
		zi = packr(z[i,.]'); // Nx1
		fi = PDF2(zi,h,tic); // ngx1
		f[i,.] = fi'; // 1xng
	endfor;
	ef = meanc(f); // ngx1
	

	xlswritem(tic~ef,"dgp1_dist.xlsx","A2",2,"");
			
end ;
