//	===========================================================================
	new;
	cls;
//	===========================================================================	
	library pgraph;
	#include FINF.SRC;
	#include UNIFORM.SRC;
	#include Disutils.SRC;
	format /rd/m1 8,4;
	rndseed 20091103;
	rho = 0.9;
	sig = 0.01;
	N = 85;
	T = 134;
	ng = 1024;
	lb = -6; // scalar
	ub = 6; // scalar
	dt = (ub-lb)/(ng-1); // scalar
	tic = seqa(lb-dt,dt,ng); // ngx1
	h = 1.06;
	tmp = xlsreadm("parameters","B2:H86",2,"");
	l1 = tmp[.,1]; // lambda
	l1[indexcat(l1.>=1,1)] = 0.99*ones(sumc(l1.>=1),1);
	g1 = tmp[.,2]; // gamma
	d1 = tmp[.,3]; // delta
	l2 = tmp[.,4]; // lambda
	l2[indexcat(l2.>=1,1)] = 0.99*ones(sumc(l2.>=1),1);
	g2 = tmp[.,5]; // gamma
	d2 = tmp[.,6]; // delta
	p1 = tmp[.,7]; // log(P(i1))

//	===========================================================================
//	Generate a wage process
//	===========================================================================
	if rho == 1;
		dw = 0;
	else;
		dw = (sig/(1-rho^2))*rndn(1,1);
	endif;
	w = zeros(T,1);
	w[1] = dw;
	w[2] = (1+rho)*w[1]+sig*rndn(1,1);
	for i (3,T,1);
		w[i] = (1+rho)*w[i-1]-rho*w[i-2]+sig*rndn(1,1);
	endfor;
	
//	===========================================================================
//	Generate sectoral prices
//	===========================================================================
	p = zeros(T,N);
	for i (1,N,1);
		a1i = l1[i]; // lambda
		b1i = g1[i]; // gamma
		c1i = d1[i]; // -delta
		a2i = l2[i]; // lambda
		b2i = g2[i]; // gamma
		c2i = d2[i]; // -delta
		p[1,i] = p1[i];
		for j (2,T,1);
			if p[j-1,i]<w[j-1];
				p[j,i] = a1i*p[j-1,i]+b1i*w[j]+c1i*w[j-1];
			else;
				p[j,i] = a2i*p[j-1,i]+b2i*w[j]+c2i*w[j-1];
			endif;
		endfor;
	endfor;
	r = p-lagn(p,1); // TxN, price changes

//	===========================================================================
//	standardised price change
//	===========================================================================
	z = zeros(T-1,N); // TxN
	for i (2,T,1);
		ri = r[i,.]'; // Nx1
		rmi = meanc(packr(ri)); // scalar
		rsi = stdc(packr(ri)); // scalar
		zi = (ri-rmi)/rsi; // Nx1
		z[i-1,.] = zi'; // 1xN
	endfor;

//	===========================================================================
//	cross-sectional distribution
//	===========================================================================
	f = zeros(T-1,ng); // Txng
	for i (1,T-1,1);
		zi = packr(z[i,.]'); // Nx1
		fi = PDF2(zi,h,tic); // ngx1
		f[i,.] = fi'; // 1xng
	endfor;
	ef = meanc(f); // ngx1
	

	xlswritem(tic~ef,"dgp2_dist.xlsx","A2",2,"");
			
end ;
