clear
set memory 5m
set matsize 3000
set linesize 255
set more off
log using "E:\MJKIM\FAR\INF\UK\moments.smcl", replace

//=============================================================================
//	load the file
//=============================================================================
	use "E:\MJKIM\FAR\INF\UK\moments.dta", clear
	tsset tid, monthly
	qui sum mu
	qui gen dmu = mu - r(mean)
	qui sum stdev
	qui gen dstdev = stdev - r(mean)
	qui sum skew
	qui gen dskew = skew - r(mean)
	qui sum kurt
	qui gen dkurt = kurt - r(mean)
	
//=============================================================================
// Autoregressive propery
//=============================================================================
//  y(t) = c + a*y(t-1) + e(t)
//  Test a = 0
//=============================================================================
	reg mu l.mu,robust // whole period
	reg stdev l.stdev,robust // whole period
	reg skew l.skew,robust // whole period
	reg kurt l.kurt,robust // whole period

//=============================================================================
// Unit root test
//=============================================================================
	dfuller mu, lags(5)
	mat urtest = (r(Zt),r(p))
	dfuller mu, lags(5) trend
	mat urtest = (urtest\r(Zt),r(p))
	dfuller stdev, lags(5)
	mat urtest = (urtest\r(Zt),r(p))
	dfuller stdev, lags(5) trend
	mat urtest = (urtest\r(Zt),r(p))
	dfuller skew, lags(5)
	mat urtest = (urtest\r(Zt),r(p))
	dfuller skew, lags(5) trend
	mat urtest = (urtest\r(Zt),r(p))
	dfuller kurt, lags(5)
	mat urtest = (urtest\r(Zt),r(p))
	dfuller kurt, lags(5) trend	
	mat urtest = (urtest\r(Zt),r(p))
	mat2txt, matrix(urtest) saving(e:\mjkim\far\inf\uk\moment_urtest.txt) replace
	 
//=============================================================================
// Contemporaneous relationship between moemnts
//=============================================================================
	reg mu stdev, robust
	reg mu skew, robust
	reg mu kurt, robust
	reg stdev skew, robust
	reg stdev kurt, robust
	reg skew kurt, robust

//=============================================================================
//	mean
//=============================================================================	
	qui sum mu
	scalar barmu = r(mean)
	qui gen consp = 1 if mu > barmu
	qui gen consn = 1 if mu <= barmu
	qui replace consp = 0 if consp == .
	qui replace consn = 0 if consn == .
	qui gen stdevp = stdev if mu > barmu
	qui gen stdevn = stdev if mu <= barmu
	qui replace stdevp = 0 if stdevp == .
	qui replace stdevn = 0 if stdevn == .
	qui gen skewp = skew if mu > barmu
	qui gen skewn = skew if mu <= barmu
	qui replace skewp = 0 if skewp == .
	qui replace skewn = 0 if skewn == .
	qui gen kurtp = kurt if mu > barmu
	qui gen kurtn = kurt if mu <= barmu
	qui replace kurtp = 0 if kurtp == .
	qui replace kurtn = 0 if kurtn == .
	reg mu consp consn stdevp stdevn, nocons robust
	test stdevp = stdevn
	reg mu consp consn skewp skewn, nocons robust 
	test skewp = skewn
	reg mu consp consn kurtp kurtn, nocons robust
	test kurtp = kurtn
	drop consp consn stdevp stdevn skewp skewn kurtp kurtn

	qui sum stdev
	scalar barstdev = r(mean)
	qui gen consp = 1 if stdev > barstdev
	qui gen consn = 1 if stdev <= barstdev
	qui replace consp = 0 if consp == .
	qui replace consn = 0 if consn == .
	qui gen skewp = skew if stdev > barstdev
	qui gen skewn = skew if stdev <= barstdev
	qui replace skewp = 0 if skewp == .
	qui replace skewn = 0 if skewn == .
	qui gen kurtp = kurt if stdev > barstdev
	qui gen kurtn = kurt if stdev <= barstdev
	qui replace kurtp = 0 if kurtp == .
	qui replace kurtn = 0 if kurtn == .
	reg stdev consp consn skewp skewn, nocons robust 
	test skewp = skewn
	reg stdev consp consn kurtp kurtn, nocons robust
	test kurtp = kurtn
	drop consp consn skewp skewn kurtp kurtn

	qui sum skew
	scalar barskew = r(mean)
	qui gen consp = 1 if skew > barskew
	qui gen consn = 1 if skew <= barskew
	qui replace consp = 0 if consp == .
	qui replace consn = 0 if consn == .
	qui gen kurtp = kurt if skew > barskew
	qui gen kurtn = kurt if skew <= barskew
	qui replace kurtp = 0 if kurtp == .
	qui replace kurtn = 0 if kurtn == .
	reg skew consp consn kurtp kurtn, nocons robust
	test kurtp = kurtn
	drop consp consn kurtp kurtn
	
log close
